# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.0.0a6

([Full Changelog](https://github.com/jupytercad/jupytercad-salome/compare/v1.0.0a5...c2ce83df6882a28abb969d8dae64133c2a284600))

### Enhancements made

- Export STL in binary format [#11](https://github.com/jupytercad/jupytercad-salome/pull/11) ([@trungleduc](https://github.com/trungleduc))

### Maintenance and upkeep improvements

- Add ui tests [#12](https://github.com/jupytercad/jupytercad-salome/pull/12) ([@trungleduc](https://github.com/trungleduc))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupytercad/jupytercad-salome/graphs/contributors?from=2023-12-22&to=2024-01-04&type=c))

[@pre-commit-ci](https://github.com/search?q=repo%3Ajupytercad%2Fjupytercad-salome+involves%3Apre-commit-ci+updated%3A2023-12-22..2024-01-04&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Ajupytercad%2Fjupytercad-salome+involves%3Atrungleduc+updated%3A2023-12-22..2024-01-04&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.0.0a5

([Full Changelog](https://github.com/jupytercad/jupytercad-salome/compare/v1.0.0a4...f43f1f98e2aa334d290e6c3aaa4a9adadb2f0f8b))

### Enhancements made

- Add error dialog [#9](https://github.com/jupytercad/jupytercad-salome/pull/9) ([@trungleduc](https://github.com/trungleduc))
- Get base url from env [#8](https://github.com/jupytercad/jupytercad-salome/pull/8) ([@trungleduc](https://github.com/trungleduc))

### Bugs fixed

- Attempt to fix the releaser workflow [#1](https://github.com/jupytercad/jupytercad-salome/pull/1) ([@martinRenou](https://github.com/martinRenou))

### Documentation improvements

- update-video [#7](https://github.com/jupytercad/jupytercad-salome/pull/7) ([@trungleduc](https://github.com/trungleduc))
- Lint readme [#6](https://github.com/jupytercad/jupytercad-salome/pull/6) ([@trungleduc](https://github.com/trungleduc))
- Add implementation details to the README [#5](https://github.com/jupytercad/jupytercad-salome/pull/5) ([@martinRenou](https://github.com/martinRenou))
- Update README [#3](https://github.com/jupytercad/jupytercad-salome/pull/3) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupytercad/jupytercad-salome/graphs/contributors?from=2023-12-21&to=2023-12-22&type=c))

[@martinRenou](https://github.com/search?q=repo%3Ajupytercad%2Fjupytercad-salome+involves%3AmartinRenou+updated%3A2023-12-21..2023-12-22&type=Issues) | [@trungleduc](https://github.com/search?q=repo%3Ajupytercad%2Fjupytercad-salome+involves%3Atrungleduc+updated%3A2023-12-21..2023-12-22&type=Issues)

## 1.0.0a4

No merged PRs
